@@ -10,6 +10,8 @@ class Webhook(object):
         """Returns for Webhook information"""
         if isinstance(url, create.Webhook) or isinstance(url, asyncCreate.Webhook):
             url = url.url
+        if "message" in requests.get(url).json() and requests.get(url).json()["message"] == "Invalid Webhook Token":
+            raise Exception("Invalid Webhook Token")
         self.webhook = requests.get(url).json()
         self.id = int(self.webhook["id"])
         self.name = self.webhook["name"]
